@@ -5,6 +5,7 @@ from django.views.decorators.csrf import csrf_exempt
 from django.views.generic import View
 
 from . import models
+from .api import UserCannotReadException
 
 
 logger = logging.getLogger(__name__)
@@ -18,11 +19,13 @@ class HookPressEndpoint(View):
 
     def post(self, request, pk, **kwargs):
         hook_used = request.POST.get('hook')
+        site = models.WPSite.objects.get(pk=pk)
         logger.info(u'Hook Triggered: {}'.format(hook_used), extra={
             'request': request,
         })
+        # TODO clean up request.POST body so it's more useful
+        models.WPLog.objects.push(site, 'hook', request.POST)
         if hook_used == 'save_post':
-            site = models.WPSite.objects.get(pk=pk)
             try:
                 post = models.WPPost.objects.get(
                     wp=site,
@@ -31,5 +34,9 @@ class HookPressEndpoint(View):
             except models.WPPost.DoesNotExist:
                 # need to create
                 post = models.WPPost(wp=site, id=request.POST.get('ID'))
-            post.fetch()
+            try:
+                post.fetch()
+            except UserCannotReadException as e:
+                # downgrade exception to INFO
+                logger.info(e)
         return HttpResponse('OK')
